@@ -1,5 +1,5 @@
 /* Perl brace format strings.
-   Copyright (C) 2003 Free Software Foundation, Inc.
+   Copyright (C) 2004 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2003.
 
    This program is free software; you can redistribute it and/or modify
@@ -62,7 +62,7 @@ named_arg_compare (const void *p1, const void *p2)
 }
 
 static void *
-format_parse (const char *format, char **invalid_reason)
+format_parse (const char *format, bool translated, char **invalid_reason)
 {
   struct spec spec;
   struct spec *result;
@@ -271,7 +271,7 @@ main ()
 	line[--line_len] = '\0';
 
       invalid_reason = NULL;
-      descr = format_parse (line, &invalid_reason);
+      descr = format_parse (line, false, &invalid_reason);
 
       format_print (descr);
       printf ("\n");
