@@ -1,5 +1,5 @@
 /* GNU gettext - internationalization aids
-   Copyright (C) 1995-1998, 2000-2003 Free Software Foundation, Inc.
+   Copyright (C) 1995-1998, 2000-2004 Free Software Foundation, Inc.
    This file was written by Peter Miller <millerp@canb.auug.org.au>
 
    This program is free software; you can redistribute it and/or modify
@@ -41,6 +41,7 @@
 #include "write-po.h"
 #include "format.h"
 #include "xalloc.h"
+#include "obstack.h"
 #include "strstr.h"
 #include "exit.h"
 #include "strcase.h"
@@ -55,6 +56,9 @@
 
 #define _(str) gettext (str)
 
+#define obstack_chunk_alloc xmalloc
+#define obstack_chunk_free free
+
 
 /* If true do not print unneeded messages.  */
 static bool quiet;
@@ -294,7 +298,7 @@ main (int argc, char **argv)
 This is free software; see the source for copying conditions.  There is NO\n\
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n\
 "),
-	      "1995-1998, 2000-2003");
+	      "1995-1998, 2000-2004");
       printf (_("Written by %s.\n"), "Peter Miller");
       exit (EXIT_SUCCESS);
     }
@@ -572,7 +576,7 @@ msgfmt_check_pair_fails (const lex_pos_ty *pos,
   struct formatstring_parser *parser = formatstring_parsers[fmt];
   char *invalid_reason = NULL;
   void *msgid_descr =
-    parser->parse (msgid_plural != NULL ? msgid_plural : msgid,
+    parser->parse (msgid_plural != NULL ? msgid_plural : msgid, false,
 		   &invalid_reason);
 
   failure = false;
@@ -583,7 +587,7 @@ msgfmt_check_pair_fails (const lex_pos_ty *pos,
 
       for (p = msgstr; p < p_end; p += strlen (p) + 1)
 	{
-	  void *msgstr_descr = parser->parse (msgstr, &invalid_reason);
+	  void *msgstr_descr = parser->parse (msgstr, true, &invalid_reason);
 
 	  if (msgstr_descr != NULL)
 	    {
@@ -661,6 +665,7 @@ message_merge (message_ty *def, message_ty *ref)
 	const char *string;
 	size_t len;
       } header_fields[UNKNOWN + 1];
+      struct obstack pool;
       const char *cp;
       char *newp;
       size_t len, cnt;
@@ -668,6 +673,9 @@ message_merge (message_ty *def, message_ty *ref)
       /* Clear all fields.  */
       memset (header_fields, '\0', sizeof (header_fields));
 
+      /* Prepare a temporary memory pool.  */
+      obstack_init (&pool);
+
       cp = def->msgstr;
       while (*cp != '\0')
 	{
@@ -682,7 +690,7 @@ message_merge (message_ty *def, message_ty *ref)
 
 	      len = endp - cp + 1;
 
-	      copy = (char *) alloca (len + 1);
+	      copy = (char *) obstack_alloc (&pool, len + 1);
 	      stpcpy (stpcpy (copy, cp), "\n");
 	      cp = copy;
 	    }
@@ -710,7 +718,8 @@ message_merge (message_ty *def, message_ty *ref)
 	      /* It's an unknown field.  Append content to what is already
 		 known.  */
 	      char *extended =
-		(char *) alloca (header_fields[UNKNOWN].len + len + 1);
+		(char *) obstack_alloc (&pool,
+					header_fields[UNKNOWN].len + len + 1);
 	      memcpy (extended, header_fields[UNKNOWN].string,
 		      header_fields[UNKNOWN].len);
 	      memcpy (&extended[header_fields[UNKNOWN].len], cp, len);
@@ -740,7 +749,7 @@ message_merge (message_ty *def, message_ty *ref)
 		char *extended;
 		endp = strchr (msgid_bugs_ptr, '\0');
 		msgid_bugs_len = (endp - msgid_bugs_ptr) + 1;
-		extended = (char *) alloca (msgid_bugs_len + 1);
+		extended = (char *) obstack_alloc (&pool, msgid_bugs_len + 1);
 		stpcpy (stpcpy (extended, msgid_bugs_ptr), "\n");
 		msgid_bugs_ptr = extended;
 	      }
@@ -770,7 +779,7 @@ message_merge (message_ty *def, message_ty *ref)
 		char *extended;
 		endp = strchr (pot_date_ptr, '\0');
 		pot_date_len = (endp - pot_date_ptr) + 1;
-		extended = (char *) alloca (pot_date_len + 1);
+		extended = (char *) obstack_alloc (&pool, pot_date_len + 1);
 		stpcpy (stpcpy (extended, pot_date_ptr), "\n");
 		pot_date_ptr = extended;
 	      }
@@ -811,6 +820,9 @@ message_merge (message_ty *def, message_ty *ref)
 
 #undef IF_FILLED
 
+      /* Free the temporary memory pool.  */
+      obstack_free (&pool, NULL);
+
       msgstr = cp;
       msgstr_len = strlen (cp) + 1;
     }
@@ -1109,7 +1121,7 @@ merge (const char *fn1, const char *fn2, msgdomain_list_ty **defp)
 	for (j = 0; j < mlp->nitems; j++)
 	  if (mlp->item[j]->msgid[0] == '\0' && !mlp->item[j]->obsolete)
 	    {
-	      const char *header = mlp->item[j]->msgstr; 
+	      const char *header = mlp->item[j]->msgstr;
 
 	      if (header != NULL)
 		{
