@@ -1,5 +1,5 @@
 /* xgettext glade backend.
-   Copyright (C) 2002 Free Software Foundation, Inc.
+   Copyright (C) 2002-2003 Free Software Foundation, Inc.
    Written by Bruno Haible <haible@clisp.cons.org>, 2002.
 
    This program is free software; you can redistribute it and/or modify
@@ -19,13 +19,15 @@
 
 #define EXTENSIONS_GLADE \
   { "glade",     "glade"    },						\
+  { "glade2",    "glade"    },						\
 
 #define SCANNERS_GLADE \
-  { "glade",      extract_glade, NULL },				\
+  { "glade",		extract_glade, NULL, NULL, NULL },		\
 
 /* Scan a glade XML file and add its translatable strings to mdlp.  */
 extern void extract_glade (FILE *fp, const char *real_filename,
 			   const char *logical_filename,
+			   flag_context_list_table_ty *flag_table,
 			   msgdomain_list_ty *mdlp);
 
 
